@@ -354,6 +354,8 @@ through only records that satisfy it. This might be used, for example,
 to specify C<source=marc> to limit search result to only to those
 FOLIO instance records that were translated from MARC imports.
 
+See the section below on B<Configuring filters>.
+
 =head2 C<graphqlQuery>
 
 The name of a file, in the same directory as the main configuration
@@ -429,7 +431,7 @@ Z39.50 record, assigned names that begin with underscores:
 
 =item C<_callNumberSuffix>
 
--item C<_permanentLocation>
+=item C<_permanentLocation>
 
 =item C<_holdingsLocation>
 
@@ -569,6 +571,30 @@ Application-specific overrides, such as those needed by the ABLE client (see iss
 
 =back
 
+=head1 CONFIGURING FILTERS
+
+By design, the FOLIO Z39.50 server follows L<the "Mechanism, Not Policy" approach|https://wiki.c2.com/?MechanismNotPolicy>: it is not opinionated about what kinds of records should be returned, how holdings should be encoded in MARC, etc. — instead, it invites institutions to configure it according to their preference.
+
+In some cases, that preference is for suppressed-from-discovery records to be omitted. So the configuration needs to be set up accordingly. The way to do this is with the C<queryFilter> configuration item, which is used to provide a query fragment that gets C<and>ed with every query submitted by the client.
+
+The configuration file could be modified to include, at the top level:
+
+  "queryFilter": "cql.allRecords=1 NOT discoverySuppress=true"
+
+This could be done either in the top-level configuration, in a database-specific configuration, or in a filter configuration.
+
+When this was used this against a good-sized institution's test service, a search for "water" found 19395 records, as opposed to 39181 when the filter was not in place. Search time remained around one or two seconds.
+
+L<A more rigorous filter|https://wiki.folio.org/display/FOLIOtips/Searching> can be used:
+
+  "queryFilter": "cql.allRecords=1 NOT discoverySuppress=true NOT holdingsItems.discoverySuppress=true NOT item.discoverySuppress=true"
+
+But as this is more complex, it has an impact on performance — as is the case when this query is used in the Inventory app's "query search". When this was used against the same institution's test service Chicago's test service, the "water" search came down to 19395 records, but it took nearly a minute to run.
+
+Or an intermediate version can be used that omits both suppressed instances and suppressed holdings, but not suppressed items. This got the result count down to 38791 — as one would expect, more than when only instances are suppress, but less then when items are also suppressed — and took two or three seconds.
+
+It's up to an individual installation to decide which trade-off best suits them. This trade-off may change as FOLIO's indexing changes: for example, if an index is added that makes the omit-instances-with-suppressed-items search much faster, that may become a more attractive option.
+
 =head1 SEE ALSO
 
 =over 4
